Crate capra_core
capra_
core
0.4.1
All Items
Crate Items
Modules
Macros
Crate
capra_
core
Diver decompression library. Includes ZHL-16 (B/C)
Modules

common
Commonly used items for decompression models and dive planning
deco
Decompression models
Macros

gas
Shorthand for creating a Gas, in a style similar to mix notation (O2/He)